from .base_classes import *
from .support_functions import *


class SecurityEvent(Resource):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage.If the element is present, it
    must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Resource
    def __init__(self, id=None, extension=None, modifierExtension=None, language=None, text=None, contained=None, event=None, participant=None, source=None, object=None):
        self.original_tagname_ = None
        super(SecurityEvent, self).__init__(id, extension, modifierExtension, language, text, contained, )
        self.event = event
        if participant is None:
            self.participant = []
        else:
            self.participant = participant
        self.source = source
        if object is None:
            self.object = []
        else:
            self.object = object
    def factory(*args_, **kwargs_):
        if SecurityEvent.subclass:
            return SecurityEvent.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_event(self): return self.event
    def set_event(self, event): self.event = event
    def get_participant(self): return self.participant
    def set_participant(self, participant): self.participant = participant
    def add_participant(self, value): self.participant.append(value)
    def insert_participant(self, index, value): self.participant[index] = value
    def get_source(self): return self.source
    def set_source(self, source): self.source = source
    def get_object(self): return self.object
    def set_object(self, object): self.object = object
    def add_object(self, value): self.object.append(value)
    def insert_object(self, index, value): self.object[index] = value
    def hasContent_(self):
        if (
            self.event is not None or
            self.participant or
            self.source is not None or
            self.object or
            super(SecurityEvent, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent'):
        super(SecurityEvent, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.event is not None:
            self.event.export(outfile, level, namespace_, name_='event', pretty_print=pretty_print)
        for participant_ in self.participant:
            participant_.export(outfile, level, namespace_, name_='participant', pretty_print=pretty_print)
        if self.source is not None:
            self.source.export(outfile, level, namespace_, name_='source', pretty_print=pretty_print)
        for object_ in self.object:
            object_.export(outfile, level, namespace_, name_='object', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent', mapping_=None):
        element = super(SecurityEvent, self).to_etree(parent_element, name_, mapping_)
        if self.event is not None:
            event_ = self.event
            event_.to_etree(element, name_='event', mapping_=mapping_)
        for participant_ in self.participant:
            participant_.to_etree(element, name_='participant', mapping_=mapping_)
        if self.source is not None:
            source_ = self.source
            source_.to_etree(element, name_='source', mapping_=mapping_)
        for object_ in self.object:
            object_.to_etree(element, name_='object', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'event':
            obj_ = SecurityEvent_Event.factory()
            obj_.build(child_)
            self.event = obj_
            obj_.original_tagname_ = 'event'
        elif nodeName_ == 'participant':
            obj_ = SecurityEvent_Participant.factory()
            obj_.build(child_)
            self.participant.append(obj_)
            obj_.original_tagname_ = 'participant'
        elif nodeName_ == 'source':
            obj_ = SecurityEvent_Source.factory()
            obj_.build(child_)
            self.source = obj_
            obj_.original_tagname_ = 'source'
        elif nodeName_ == 'object':
            obj_ = SecurityEvent_Object.factory()
            obj_.build(child_)
            self.object.append(obj_)
            obj_.original_tagname_ = 'object'
        super(SecurityEvent, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent


class SecurityEvent_Event(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, type_=None, subtype=None, action=None, dateTime=None, outcome=None, outcomeDesc=None):
        self.original_tagname_ = None
        super(SecurityEvent_Event, self).__init__(id, extension, modifierExtension, )
        self.type_ = type_
        if subtype is None:
            self.subtype = []
        else:
            self.subtype = subtype
        self.action = action
        self.dateTime = dateTime
        self.outcome = outcome
        self.outcomeDesc = outcomeDesc
    def factory(*args_, **kwargs_):
        if SecurityEvent_Event.subclass:
            return SecurityEvent_Event.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Event(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_subtype(self): return self.subtype
    def set_subtype(self, subtype): self.subtype = subtype
    def add_subtype(self, value): self.subtype.append(value)
    def insert_subtype(self, index, value): self.subtype[index] = value
    def get_action(self): return self.action
    def set_action(self, action): self.action = action
    def get_dateTime(self): return self.dateTime
    def set_dateTime(self, dateTime): self.dateTime = dateTime
    def get_outcome(self): return self.outcome
    def set_outcome(self, outcome): self.outcome = outcome
    def get_outcomeDesc(self): return self.outcomeDesc
    def set_outcomeDesc(self, outcomeDesc): self.outcomeDesc = outcomeDesc
    def hasContent_(self):
        if (
            self.type_ is not None or
            self.subtype or
            self.action is not None or
            self.dateTime is not None or
            self.outcome is not None or
            self.outcomeDesc is not None or
            super(SecurityEvent_Event, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Event', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Event')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Event', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Event'):
        super(SecurityEvent_Event, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Event')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Event', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Event, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        for subtype_ in self.subtype:
            subtype_.export(outfile, level, namespace_, name_='subtype', pretty_print=pretty_print)
        if self.action is not None:
            self.action.export(outfile, level, namespace_, name_='action', pretty_print=pretty_print)
        if self.dateTime is not None:
            self.dateTime.export(outfile, level, namespace_, name_='dateTime', pretty_print=pretty_print)
        if self.outcome is not None:
            self.outcome.export(outfile, level, namespace_, name_='outcome', pretty_print=pretty_print)
        if self.outcomeDesc is not None:
            self.outcomeDesc.export(outfile, level, namespace_, name_='outcomeDesc', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Event', mapping_=None):
        element = super(SecurityEvent_Event, self).to_etree(parent_element, name_, mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        for subtype_ in self.subtype:
            subtype_.to_etree(element, name_='subtype', mapping_=mapping_)
        if self.action is not None:
            action_ = self.action
            action_.to_etree(element, name_='action', mapping_=mapping_)
        if self.dateTime is not None:
            dateTime_ = self.dateTime
            dateTime_.to_etree(element, name_='dateTime', mapping_=mapping_)
        if self.outcome is not None:
            outcome_ = self.outcome
            outcome_.to_etree(element, name_='outcome', mapping_=mapping_)
        if self.outcomeDesc is not None:
            outcomeDesc_ = self.outcomeDesc
            outcomeDesc_.to_etree(element, name_='outcomeDesc', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Event, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'type':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'subtype':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.subtype.append(obj_)
            obj_.original_tagname_ = 'subtype'
        elif nodeName_ == 'action':
            obj_ = SecurityEventAction.factory()
            obj_.build(child_)
            self.action = obj_
            obj_.original_tagname_ = 'action'
        elif nodeName_ == 'dateTime':
            obj_ = instant.factory()
            obj_.build(child_)
            self.dateTime = obj_
            obj_.original_tagname_ = 'dateTime'
        elif nodeName_ == 'outcome':
            obj_ = SecurityEventOutcome.factory()
            obj_.build(child_)
            self.outcome = obj_
            obj_.original_tagname_ = 'outcome'
        elif nodeName_ == 'outcomeDesc':
            obj_ = string.factory()
            obj_.build(child_)
            self.outcomeDesc = obj_
            obj_.original_tagname_ = 'outcomeDesc'
        super(SecurityEvent_Event, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Event


class SecurityEvent_Participant(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, role=None, reference=None, userId=None, altId=None, name=None, requestor=None, media=None, network=None):
        self.original_tagname_ = None
        super(SecurityEvent_Participant, self).__init__(id, extension, modifierExtension, )
        if role is None:
            self.role = []
        else:
            self.role = role
        self.reference = reference
        self.userId = userId
        self.altId = altId
        self.name = name
        self.requestor = requestor
        self.media = media
        self.network = network
    def factory(*args_, **kwargs_):
        if SecurityEvent_Participant.subclass:
            return SecurityEvent_Participant.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Participant(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_role(self): return self.role
    def set_role(self, role): self.role = role
    def add_role(self, value): self.role.append(value)
    def insert_role(self, index, value): self.role[index] = value
    def get_reference(self): return self.reference
    def set_reference(self, reference): self.reference = reference
    def get_userId(self): return self.userId
    def set_userId(self, userId): self.userId = userId
    def get_altId(self): return self.altId
    def set_altId(self, altId): self.altId = altId
    def get_name(self): return self.name
    def set_name(self, name): self.name = name
    def get_requestor(self): return self.requestor
    def set_requestor(self, requestor): self.requestor = requestor
    def get_media(self): return self.media
    def set_media(self, media): self.media = media
    def get_network(self): return self.network
    def set_network(self, network): self.network = network
    def hasContent_(self):
        if (
            self.role or
            self.reference is not None or
            self.userId is not None or
            self.altId is not None or
            self.name is not None or
            self.requestor is not None or
            self.media is not None or
            self.network is not None or
            super(SecurityEvent_Participant, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Participant', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Participant')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Participant', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Participant'):
        super(SecurityEvent_Participant, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Participant')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Participant', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Participant, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        for role_ in self.role:
            role_.export(outfile, level, namespace_, name_='role', pretty_print=pretty_print)
        if self.reference is not None:
            self.reference.export(outfile, level, namespace_, name_='reference', pretty_print=pretty_print)
        if self.userId is not None:
            self.userId.export(outfile, level, namespace_, name_='userId', pretty_print=pretty_print)
        if self.altId is not None:
            self.altId.export(outfile, level, namespace_, name_='altId', pretty_print=pretty_print)
        if self.name is not None:
            self.name.export(outfile, level, namespace_, name_='name', pretty_print=pretty_print)
        if self.requestor is not None:
            self.requestor.export(outfile, level, namespace_, name_='requestor', pretty_print=pretty_print)
        if self.media is not None:
            self.media.export(outfile, level, namespace_, name_='media', pretty_print=pretty_print)
        if self.network is not None:
            self.network.export(outfile, level, namespace_, name_='network', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Participant', mapping_=None):
        element = super(SecurityEvent_Participant, self).to_etree(parent_element, name_, mapping_)
        for role_ in self.role:
            role_.to_etree(element, name_='role', mapping_=mapping_)
        if self.reference is not None:
            reference_ = self.reference
            reference_.to_etree(element, name_='reference', mapping_=mapping_)
        if self.userId is not None:
            userId_ = self.userId
            userId_.to_etree(element, name_='userId', mapping_=mapping_)
        if self.altId is not None:
            altId_ = self.altId
            altId_.to_etree(element, name_='altId', mapping_=mapping_)
        if self.name is not None:
            name_ = self.name
            name_.to_etree(element, name_='name', mapping_=mapping_)
        if self.requestor is not None:
            requestor_ = self.requestor
            requestor_.to_etree(element, name_='requestor', mapping_=mapping_)
        if self.media is not None:
            media_ = self.media
            media_.to_etree(element, name_='media', mapping_=mapping_)
        if self.network is not None:
            network_ = self.network
            network_.to_etree(element, name_='network', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Participant, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'role':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.role.append(obj_)
            obj_.original_tagname_ = 'role'
        elif nodeName_ == 'reference':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.reference = obj_
            obj_.original_tagname_ = 'reference'
        elif nodeName_ == 'userId':
            obj_ = string.factory()
            obj_.build(child_)
            self.userId = obj_
            obj_.original_tagname_ = 'userId'
        elif nodeName_ == 'altId':
            obj_ = string.factory()
            obj_.build(child_)
            self.altId = obj_
            obj_.original_tagname_ = 'altId'
        elif nodeName_ == 'name':
            obj_ = string.factory()
            obj_.build(child_)
            self.name = obj_
            obj_.original_tagname_ = 'name'
        elif nodeName_ == 'requestor':
            obj_ = boolean.factory()
            obj_.build(child_)
            self.requestor = obj_
            obj_.original_tagname_ = 'requestor'
        elif nodeName_ == 'media':
            obj_ = Coding.factory()
            obj_.build(child_)
            self.media = obj_
            obj_.original_tagname_ = 'media'
        elif nodeName_ == 'network':
            obj_ = SecurityEvent_Network.factory()
            obj_.build(child_)
            self.network = obj_
            obj_.original_tagname_ = 'network'
        super(SecurityEvent_Participant, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Participant


class SecurityEvent_Network(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, identifier=None, type_=None):
        self.original_tagname_ = None
        super(SecurityEvent_Network, self).__init__(id, extension, modifierExtension, )
        self.identifier = identifier
        self.type_ = type_
    def factory(*args_, **kwargs_):
        if SecurityEvent_Network.subclass:
            return SecurityEvent_Network.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Network(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def hasContent_(self):
        if (
            self.identifier is not None or
            self.type_ is not None or
            super(SecurityEvent_Network, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Network', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Network')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Network', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Network'):
        super(SecurityEvent_Network, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Network')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Network', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Network, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.identifier is not None:
            self.identifier.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Network', mapping_=None):
        element = super(SecurityEvent_Network, self).to_etree(parent_element, name_, mapping_)
        if self.identifier is not None:
            identifier_ = self.identifier
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Network, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'identifier':
            obj_ = string.factory()
            obj_.build(child_)
            self.identifier = obj_
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'type':
            obj_ = SecurityEventParticipantNetworkType.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        super(SecurityEvent_Network, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Network


class SecurityEvent_Source(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, site=None, identifier=None, type_=None):
        self.original_tagname_ = None
        super(SecurityEvent_Source, self).__init__(id, extension, modifierExtension, )
        self.site = site
        self.identifier = identifier
        if type_ is None:
            self.type_ = []
        else:
            self.type_ = type_
    def factory(*args_, **kwargs_):
        if SecurityEvent_Source.subclass:
            return SecurityEvent_Source.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Source(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_site(self): return self.site
    def set_site(self, site): self.site = site
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def add_type(self, value): self.type_.append(value)
    def insert_type(self, index, value): self.type_[index] = value
    def hasContent_(self):
        if (
            self.site is not None or
            self.identifier is not None or
            self.type_ or
            super(SecurityEvent_Source, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Source', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Source')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Source', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Source'):
        super(SecurityEvent_Source, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Source')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Source', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Source, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.site is not None:
            self.site.export(outfile, level, namespace_, name_='site', pretty_print=pretty_print)
        if self.identifier is not None:
            self.identifier.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        for type_ in self.type_:
            type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Source', mapping_=None):
        element = super(SecurityEvent_Source, self).to_etree(parent_element, name_, mapping_)
        if self.site is not None:
            site_ = self.site
            site_.to_etree(element, name_='site', mapping_=mapping_)
        if self.identifier is not None:
            identifier_ = self.identifier
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        for type__ in self.type_:
            type__.to_etree(element, name_='type', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Source, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'site':
            obj_ = string.factory()
            obj_.build(child_)
            self.site = obj_
            obj_.original_tagname_ = 'site'
        elif nodeName_ == 'identifier':
            obj_ = string.factory()
            obj_.build(child_)
            self.identifier = obj_
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'type':
            obj_ = Coding.factory()
            obj_.build(child_)
            self.type_.append(obj_)
            obj_.original_tagname_ = 'type'
        super(SecurityEvent_Source, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Source


class SecurityEvent_Object(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, identifier=None, reference=None, type_=None, role=None, lifecycle=None, sensitivity=None, name=None, description=None, query=None, detail=None):
        self.original_tagname_ = None
        super(SecurityEvent_Object, self).__init__(id, extension, modifierExtension, )
        self.identifier = identifier
        self.reference = reference
        self.type_ = type_
        self.role = role
        self.lifecycle = lifecycle
        self.sensitivity = sensitivity
        self.name = name
        self.description = description
        self.query = query
        if detail is None:
            self.detail = []
        else:
            self.detail = detail
    def factory(*args_, **kwargs_):
        if SecurityEvent_Object.subclass:
            return SecurityEvent_Object.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Object(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def get_reference(self): return self.reference
    def set_reference(self, reference): self.reference = reference
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_role(self): return self.role
    def set_role(self, role): self.role = role
    def get_lifecycle(self): return self.lifecycle
    def set_lifecycle(self, lifecycle): self.lifecycle = lifecycle
    def get_sensitivity(self): return self.sensitivity
    def set_sensitivity(self, sensitivity): self.sensitivity = sensitivity
    def get_name(self): return self.name
    def set_name(self, name): self.name = name
    def get_description(self): return self.description
    def set_description(self, description): self.description = description
    def get_query(self): return self.query
    def set_query(self, query): self.query = query
    def get_detail(self): return self.detail
    def set_detail(self, detail): self.detail = detail
    def add_detail(self, value): self.detail.append(value)
    def insert_detail(self, index, value): self.detail[index] = value
    def hasContent_(self):
        if (
            self.identifier is not None or
            self.reference is not None or
            self.type_ is not None or
            self.role is not None or
            self.lifecycle is not None or
            self.sensitivity is not None or
            self.name is not None or
            self.description is not None or
            self.query is not None or
            self.detail or
            super(SecurityEvent_Object, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Object', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Object')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Object', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Object'):
        super(SecurityEvent_Object, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Object')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Object', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Object, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.identifier is not None:
            self.identifier.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        if self.reference is not None:
            self.reference.export(outfile, level, namespace_, name_='reference', pretty_print=pretty_print)
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        if self.role is not None:
            self.role.export(outfile, level, namespace_, name_='role', pretty_print=pretty_print)
        if self.lifecycle is not None:
            self.lifecycle.export(outfile, level, namespace_, name_='lifecycle', pretty_print=pretty_print)
        if self.sensitivity is not None:
            self.sensitivity.export(outfile, level, namespace_, name_='sensitivity', pretty_print=pretty_print)
        if self.name is not None:
            self.name.export(outfile, level, namespace_, name_='name', pretty_print=pretty_print)
        if self.description is not None:
            self.description.export(outfile, level, namespace_, name_='description', pretty_print=pretty_print)
        if self.query is not None:
            self.query.export(outfile, level, namespace_, name_='query', pretty_print=pretty_print)
        for detail_ in self.detail:
            detail_.export(outfile, level, namespace_, name_='detail', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Object', mapping_=None):
        element = super(SecurityEvent_Object, self).to_etree(parent_element, name_, mapping_)
        if self.identifier is not None:
            identifier_ = self.identifier
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        if self.reference is not None:
            reference_ = self.reference
            reference_.to_etree(element, name_='reference', mapping_=mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        if self.role is not None:
            role_ = self.role
            role_.to_etree(element, name_='role', mapping_=mapping_)
        if self.lifecycle is not None:
            lifecycle_ = self.lifecycle
            lifecycle_.to_etree(element, name_='lifecycle', mapping_=mapping_)
        if self.sensitivity is not None:
            sensitivity_ = self.sensitivity
            sensitivity_.to_etree(element, name_='sensitivity', mapping_=mapping_)
        if self.name is not None:
            name_ = self.name
            name_.to_etree(element, name_='name', mapping_=mapping_)
        if self.description is not None:
            description_ = self.description
            description_.to_etree(element, name_='description', mapping_=mapping_)
        if self.query is not None:
            query_ = self.query
            query_.to_etree(element, name_='query', mapping_=mapping_)
        for detail_ in self.detail:
            detail_.to_etree(element, name_='detail', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Object, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'identifier':
            obj_ = Identifier.factory()
            obj_.build(child_)
            self.identifier = obj_
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'reference':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.reference = obj_
            obj_.original_tagname_ = 'reference'
        elif nodeName_ == 'type':
            obj_ = SecurityEventObjectType.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'role':
            obj_ = SecurityEventObjectRole.factory()
            obj_.build(child_)
            self.role = obj_
            obj_.original_tagname_ = 'role'
        elif nodeName_ == 'lifecycle':
            obj_ = SecurityEventObjectLifecycle.factory()
            obj_.build(child_)
            self.lifecycle = obj_
            obj_.original_tagname_ = 'lifecycle'
        elif nodeName_ == 'sensitivity':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.sensitivity = obj_
            obj_.original_tagname_ = 'sensitivity'
        elif nodeName_ == 'name':
            obj_ = string.factory()
            obj_.build(child_)
            self.name = obj_
            obj_.original_tagname_ = 'name'
        elif nodeName_ == 'description':
            obj_ = string.factory()
            obj_.build(child_)
            self.description = obj_
            obj_.original_tagname_ = 'description'
        elif nodeName_ == 'query':
            obj_ = base64Binary.factory()
            obj_.build(child_)
            self.query = obj_
            obj_.original_tagname_ = 'query'
        elif nodeName_ == 'detail':
            obj_ = SecurityEvent_Detail.factory()
            obj_.build(child_)
            self.detail.append(obj_)
            obj_.original_tagname_ = 'detail'
        super(SecurityEvent_Object, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Object


class SecurityEvent_Detail(BackboneElement):
    """A record of an event made for purposes of maintaining a security
    log. Typical uses include detection of intrusion attempts and
    monitoring for inappropriate usage."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, type_=None, value=None):
        self.original_tagname_ = None
        super(SecurityEvent_Detail, self).__init__(id, extension, modifierExtension, )
        self.type_ = type_
        self.value = value
    def factory(*args_, **kwargs_):
        if SecurityEvent_Detail.subclass:
            return SecurityEvent_Detail.subclass(*args_, **kwargs_)
        else:
            return SecurityEvent_Detail(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            self.type_ is not None or
            self.value is not None or
            super(SecurityEvent_Detail, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEvent.Detail', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Detail')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEvent.Detail', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEvent.Detail'):
        super(SecurityEvent_Detail, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEvent.Detail')
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEvent.Detail', fromsubclass_=False, pretty_print=True):
        super(SecurityEvent_Detail, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        if self.value is not None:
            self.value.export(outfile, level, namespace_, name_='value', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEvent.Detail', mapping_=None):
        element = super(SecurityEvent_Detail, self).to_etree(parent_element, name_, mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        if self.value is not None:
            value_ = self.value
            value_.to_etree(element, name_='value', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(SecurityEvent_Detail, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'type':
            obj_ = string.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'value':
            obj_ = base64Binary.factory()
            obj_.build(child_)
            self.value = obj_
            obj_.original_tagname_ = 'value'
        super(SecurityEvent_Detail, self).buildChildren(child_, node, nodeName_, True)
# end class SecurityEvent_Detail


class SecurityEventObjectRole(Element):
    """Code representing the functional application role of Participant
    Object being auditedIf the element is present, it must have
    either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventObjectRole, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventObjectRole.subclass:
            return SecurityEventObjectRole.subclass(*args_, **kwargs_)
        else:
            return SecurityEventObjectRole(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventObjectRole, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventObjectRole', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectRole')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventObjectRole', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventObjectRole'):
        super(SecurityEventObjectRole, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectRole')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventObjectRole', fromsubclass_=False, pretty_print=True):
        super(SecurityEventObjectRole, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventObjectRole', mapping_=None):
        element = super(SecurityEventObjectRole, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventObjectRole, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventObjectRole, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventObjectRole


class SecurityEventObjectType(Element):
    """Code for the participant object type being auditedIf the element is
    present, it must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventObjectType, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventObjectType.subclass:
            return SecurityEventObjectType.subclass(*args_, **kwargs_)
        else:
            return SecurityEventObjectType(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventObjectType, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventObjectType', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectType')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventObjectType', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventObjectType'):
        super(SecurityEventObjectType, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectType')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventObjectType', fromsubclass_=False, pretty_print=True):
        super(SecurityEventObjectType, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventObjectType', mapping_=None):
        element = super(SecurityEventObjectType, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventObjectType, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventObjectType, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventObjectType


class SecurityEventAction(Element):
    """Indicator for type of action performed during the event that
    generated the audit.If the element is present, it must have
    either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventAction, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventAction.subclass:
            return SecurityEventAction.subclass(*args_, **kwargs_)
        else:
            return SecurityEventAction(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventAction, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventAction', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventAction')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventAction', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventAction'):
        super(SecurityEventAction, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventAction')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventAction', fromsubclass_=False, pretty_print=True):
        super(SecurityEventAction, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventAction', mapping_=None):
        element = super(SecurityEventAction, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventAction, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventAction, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventAction


class SecurityEventObjectLifecycle(Element):
    """Identifier for the data life-cycle stage for the participant
    objectIf the element is present, it must have either a @value,
    an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventObjectLifecycle, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventObjectLifecycle.subclass:
            return SecurityEventObjectLifecycle.subclass(*args_, **kwargs_)
        else:
            return SecurityEventObjectLifecycle(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventObjectLifecycle, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventObjectLifecycle', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectLifecycle')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventObjectLifecycle', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventObjectLifecycle'):
        super(SecurityEventObjectLifecycle, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventObjectLifecycle')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventObjectLifecycle', fromsubclass_=False, pretty_print=True):
        super(SecurityEventObjectLifecycle, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventObjectLifecycle', mapping_=None):
        element = super(SecurityEventObjectLifecycle, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventObjectLifecycle, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventObjectLifecycle, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventObjectLifecycle


class SecurityEventParticipantNetworkType(Element):
    """The type of network access point that originated the audit eventIf
    the element is present, it must have either a @value, an @id, or
    extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventParticipantNetworkType, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventParticipantNetworkType.subclass:
            return SecurityEventParticipantNetworkType.subclass(*args_, **kwargs_)
        else:
            return SecurityEventParticipantNetworkType(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventParticipantNetworkType, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventParticipantNetworkType', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventParticipantNetworkType')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventParticipantNetworkType', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventParticipantNetworkType'):
        super(SecurityEventParticipantNetworkType, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventParticipantNetworkType')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventParticipantNetworkType', fromsubclass_=False, pretty_print=True):
        super(SecurityEventParticipantNetworkType, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventParticipantNetworkType', mapping_=None):
        element = super(SecurityEventParticipantNetworkType, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventParticipantNetworkType, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventParticipantNetworkType, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventParticipantNetworkType


class SecurityEventOutcome(Element):
    """Indicates whether the event succeeded or failedIf the element is
    present, it must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(SecurityEventOutcome, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if SecurityEventOutcome.subclass:
            return SecurityEventOutcome.subclass(*args_, **kwargs_)
        else:
            return SecurityEventOutcome(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(SecurityEventOutcome, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='SecurityEventOutcome', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventOutcome')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='SecurityEventOutcome', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='SecurityEventOutcome'):
        super(SecurityEventOutcome, self).exportAttributes(outfile, level, already_processed, namespace_, name_='SecurityEventOutcome')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='SecurityEventOutcome', fromsubclass_=False, pretty_print=True):
        super(SecurityEventOutcome, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='SecurityEventOutcome', mapping_=None):
        element = super(SecurityEventOutcome, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(SecurityEventOutcome, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(SecurityEventOutcome, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class SecurityEventOutcome



#!/usr/bin/env python

##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2017 Luis Falcon <falcon@gnu.org>
#    Copyright (C) 2011-2017 GNU Solidario <health@gnusolidario.org>
#
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import argparse
import getpass
import os
import sys
import crypt
import random
import string
import configparser

try:
    import cracklib
except ImportError:
    print ("Cracklib not installed. Please install the library and try again")
    sys.exit(-1)

config_file = ""
  
parser = argparse.ArgumentParser()

parser.add_argument("-c", "--config",
    help="Specify alternative Tryton configuration file")

args = parser.parse_args()

try: 
    config_file = os.environ['TRYTOND_CONFIG']
except:
    pass

if args.config:
    config_file = args.config

if not config_file:
    print ("TRYTOND_CONFIG variable not set and No configuration file specified")
    sys.exit(-1)



    
print ("Using Tryton configuration file "), config_file
        
def validate_password():
    passwd = getpass.getpass()
    print ("Again")
    passwd2 = getpass.getpass()
    
    if (passwd != passwd2):
        print ("Password mismatch")
        return validate_password()
        
    """Check against cracklib to avoid simple passwords"""
    try: 
        cracklib.VeryFascistCheck (passwd)
    except ValueError as msg:
        print (msg)
        return validate_password()
      
    return passwd    

config = configparser.RawConfigParser()
config.read(config_file)

if not 'session' in config.sections():
    config.add_section('session')

trytond_pass = validate_password()

salt =  "".join(random.sample(string.ascii_letters + string.digits, 8))

encrypted_passwd = crypt.crypt(trytond_pass, salt)

config.set ('session','super_pwd',encrypted_passwd)

output_file = open(config_file,'w')
config.write(output_file)

print ("Configuration file updated with new password !")



from .base_classes import *
from .support_functions import *


class Condition(Resource):
    """Use to record detailed information about conditions, problems or
    diagnoses recognized by a clinician. There are many uses
    including: recording a Diagnosis during an Encounter; populating
    a problem List or a Summary Statement, such as a Discharge
    Summary.If the element is present, it must have either a @value,
    an @id, or extensionsEstimated or actual date the condition
    began, in the opinion of the clinician.The date or estimated
    date that the condition resolved or went into remission. This is
    called "abatement" because of the many overloaded connotations
    associated with "remission" or "resolution" - Conditions are
    never really resolved, but they can abate."""
    subclass = None
    superclass = Resource
    def __init__(self, id=None, extension=None, modifierExtension=None, language=None, text=None, contained=None, identifier=None, subject=None, encounter=None, asserter=None, dateAsserted=None, code=None, category=None, status=None, certainty=None, severity=None, onsetDate=None, onsetAge=None, abatementDate=None, abatementAge=None, abatementBoolean=None, stage=None, evidence=None, location=None, relatedItem=None, notes=None):
        self.original_tagname_ = None
        super(Condition, self).__init__(id, extension, modifierExtension, language, text, contained, )
        if identifier is None:
            self.identifier = []
        else:
            self.identifier = identifier
        self.subject = subject
        self.encounter = encounter
        self.asserter = asserter
        self.dateAsserted = dateAsserted
        self.code = code
        self.category = category
        self.status = status
        self.certainty = certainty
        self.severity = severity
        self.onsetDate = onsetDate
        self.onsetAge = onsetAge
        self.abatementDate = abatementDate
        self.abatementAge = abatementAge
        self.abatementBoolean = abatementBoolean
        self.stage = stage
        if evidence is None:
            self.evidence = []
        else:
            self.evidence = evidence
        if location is None:
            self.location = []
        else:
            self.location = location
        if relatedItem is None:
            self.relatedItem = []
        else:
            self.relatedItem = relatedItem
        self.notes = notes
    def factory(*args_, **kwargs_):
        if Condition.subclass:
            return Condition.subclass(*args_, **kwargs_)
        else:
            return Condition(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def add_identifier(self, value): self.identifier.append(value)
    def insert_identifier(self, index, value): self.identifier[index] = value
    def get_subject(self): return self.subject
    def set_subject(self, subject): self.subject = subject
    def get_encounter(self): return self.encounter
    def set_encounter(self, encounter): self.encounter = encounter
    def get_asserter(self): return self.asserter
    def set_asserter(self, asserter): self.asserter = asserter
    def get_dateAsserted(self): return self.dateAsserted
    def set_dateAsserted(self, dateAsserted): self.dateAsserted = dateAsserted
    def get_code(self): return self.code
    def set_code(self, code): self.code = code
    def get_category(self): return self.category
    def set_category(self, category): self.category = category
    def get_status(self): return self.status
    def set_status(self, status): self.status = status
    def get_certainty(self): return self.certainty
    def set_certainty(self, certainty): self.certainty = certainty
    def get_severity(self): return self.severity
    def set_severity(self, severity): self.severity = severity
    def get_onsetDate(self): return self.onsetDate
    def set_onsetDate(self, onsetDate): self.onsetDate = onsetDate
    def get_onsetAge(self): return self.onsetAge
    def set_onsetAge(self, onsetAge): self.onsetAge = onsetAge
    def get_abatementDate(self): return self.abatementDate
    def set_abatementDate(self, abatementDate): self.abatementDate = abatementDate
    def get_abatementAge(self): return self.abatementAge
    def set_abatementAge(self, abatementAge): self.abatementAge = abatementAge
    def get_abatementBoolean(self): return self.abatementBoolean
    def set_abatementBoolean(self, abatementBoolean): self.abatementBoolean = abatementBoolean
    def get_stage(self): return self.stage
    def set_stage(self, stage): self.stage = stage
    def get_evidence(self): return self.evidence
    def set_evidence(self, evidence): self.evidence = evidence
    def add_evidence(self, value): self.evidence.append(value)
    def insert_evidence(self, index, value): self.evidence[index] = value
    def get_location(self): return self.location
    def set_location(self, location): self.location = location
    def add_location(self, value): self.location.append(value)
    def insert_location(self, index, value): self.location[index] = value
    def get_relatedItem(self): return self.relatedItem
    def set_relatedItem(self, relatedItem): self.relatedItem = relatedItem
    def add_relatedItem(self, value): self.relatedItem.append(value)
    def insert_relatedItem(self, index, value): self.relatedItem[index] = value
    def get_notes(self): return self.notes
    def set_notes(self, notes): self.notes = notes
    def hasContent_(self):
        if (
            self.identifier or
            self.subject is not None or
            self.encounter is not None or
            self.asserter is not None or
            self.dateAsserted is not None or
            self.code is not None or
            self.category is not None or
            self.status is not None or
            self.certainty is not None or
            self.severity is not None or
            self.onsetDate is not None or
            self.onsetAge is not None or
            self.abatementDate is not None or
            self.abatementAge is not None or
            self.abatementBoolean is not None or
            self.stage is not None or
            self.evidence or
            self.location or
            self.relatedItem or
            self.notes is not None or
            super(Condition, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Condition', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Condition')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Condition', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Condition'):
        super(Condition, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Condition')
    def exportChildren(self, outfile, level, namespace_='', name_='Condition', fromsubclass_=False, pretty_print=True):
        super(Condition, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        for identifier_ in self.identifier:
            identifier_.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        if self.subject is not None:
            self.subject.export(outfile, level, namespace_, name_='subject', pretty_print=pretty_print)
        if self.encounter is not None:
            self.encounter.export(outfile, level, namespace_, name_='encounter', pretty_print=pretty_print)
        if self.asserter is not None:
            self.asserter.export(outfile, level, namespace_, name_='asserter', pretty_print=pretty_print)
        if self.dateAsserted is not None:
            self.dateAsserted.export(outfile, level, namespace_, name_='dateAsserted', pretty_print=pretty_print)
        if self.code is not None:
            self.code.export(outfile, level, namespace_, name_='code', pretty_print=pretty_print)
        if self.category is not None:
            self.category.export(outfile, level, namespace_, name_='category', pretty_print=pretty_print)
        if self.status is not None:
            self.status.export(outfile, level, namespace_, name_='status', pretty_print=pretty_print)
        if self.certainty is not None:
            self.certainty.export(outfile, level, namespace_, name_='certainty', pretty_print=pretty_print)
        if self.severity is not None:
            self.severity.export(outfile, level, namespace_, name_='severity', pretty_print=pretty_print)
        if self.onsetDate is not None:
            self.onsetDate.export(outfile, level, namespace_, name_='onsetDate', pretty_print=pretty_print)
        if self.onsetAge is not None:
            self.onsetAge.export(outfile, level, namespace_, name_='onsetAge', pretty_print=pretty_print)
        if self.abatementDate is not None:
            self.abatementDate.export(outfile, level, namespace_, name_='abatementDate', pretty_print=pretty_print)
        if self.abatementAge is not None:
            self.abatementAge.export(outfile, level, namespace_, name_='abatementAge', pretty_print=pretty_print)
        if self.abatementBoolean is not None:
            self.abatementBoolean.export(outfile, level, namespace_, name_='abatementBoolean', pretty_print=pretty_print)
        if self.stage is not None:
            self.stage.export(outfile, level, namespace_, name_='stage', pretty_print=pretty_print)
        for evidence_ in self.evidence:
            evidence_.export(outfile, level, namespace_, name_='evidence', pretty_print=pretty_print)
        for location_ in self.location:
            location_.export(outfile, level, namespace_, name_='location', pretty_print=pretty_print)
        for relatedItem_ in self.relatedItem:
            relatedItem_.export(outfile, level, namespace_, name_='relatedItem', pretty_print=pretty_print)
        if self.notes is not None:
            self.notes.export(outfile, level, namespace_, name_='notes', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Condition', mapping_=None):
        element = super(Condition, self).to_etree(parent_element, name_, mapping_)
        for identifier_ in self.identifier:
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        if self.subject is not None:
            subject_ = self.subject
            subject_.to_etree(element, name_='subject', mapping_=mapping_)
        if self.encounter is not None:
            encounter_ = self.encounter
            encounter_.to_etree(element, name_='encounter', mapping_=mapping_)
        if self.asserter is not None:
            asserter_ = self.asserter
            asserter_.to_etree(element, name_='asserter', mapping_=mapping_)
        if self.dateAsserted is not None:
            dateAsserted_ = self.dateAsserted
            dateAsserted_.to_etree(element, name_='dateAsserted', mapping_=mapping_)
        if self.code is not None:
            code_ = self.code
            code_.to_etree(element, name_='code', mapping_=mapping_)
        if self.category is not None:
            category_ = self.category
            category_.to_etree(element, name_='category', mapping_=mapping_)
        if self.status is not None:
            status_ = self.status
            status_.to_etree(element, name_='status', mapping_=mapping_)
        if self.certainty is not None:
            certainty_ = self.certainty
            certainty_.to_etree(element, name_='certainty', mapping_=mapping_)
        if self.severity is not None:
            severity_ = self.severity
            severity_.to_etree(element, name_='severity', mapping_=mapping_)
        if self.onsetDate is not None:
            onsetDate_ = self.onsetDate
            onsetDate_.to_etree(element, name_='onsetDate', mapping_=mapping_)
        if self.onsetAge is not None:
            onsetAge_ = self.onsetAge
            onsetAge_.to_etree(element, name_='onsetAge', mapping_=mapping_)
        if self.abatementDate is not None:
            abatementDate_ = self.abatementDate
            abatementDate_.to_etree(element, name_='abatementDate', mapping_=mapping_)
        if self.abatementAge is not None:
            abatementAge_ = self.abatementAge
            abatementAge_.to_etree(element, name_='abatementAge', mapping_=mapping_)
        if self.abatementBoolean is not None:
            abatementBoolean_ = self.abatementBoolean
            abatementBoolean_.to_etree(element, name_='abatementBoolean', mapping_=mapping_)
        if self.stage is not None:
            stage_ = self.stage
            stage_.to_etree(element, name_='stage', mapping_=mapping_)
        for evidence_ in self.evidence:
            evidence_.to_etree(element, name_='evidence', mapping_=mapping_)
        for location_ in self.location:
            location_.to_etree(element, name_='location', mapping_=mapping_)
        for relatedItem_ in self.relatedItem:
            relatedItem_.to_etree(element, name_='relatedItem', mapping_=mapping_)
        if self.notes is not None:
            notes_ = self.notes
            notes_.to_etree(element, name_='notes', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Condition, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'identifier':
            obj_ = Identifier.factory()
            obj_.build(child_)
            self.identifier.append(obj_)
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'subject':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.subject = obj_
            obj_.original_tagname_ = 'subject'
        elif nodeName_ == 'encounter':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.encounter = obj_
            obj_.original_tagname_ = 'encounter'
        elif nodeName_ == 'asserter':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.asserter = obj_
            obj_.original_tagname_ = 'asserter'
        elif nodeName_ == 'dateAsserted':
            obj_ = date.factory()
            obj_.build(child_)
            self.dateAsserted = obj_
            obj_.original_tagname_ = 'dateAsserted'
        elif nodeName_ == 'code':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.code = obj_
            obj_.original_tagname_ = 'code'
        elif nodeName_ == 'category':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.category = obj_
            obj_.original_tagname_ = 'category'
        elif nodeName_ == 'status':
            obj_ = ConditionStatus.factory()
            obj_.build(child_)
            self.status = obj_
            obj_.original_tagname_ = 'status'
        elif nodeName_ == 'certainty':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.certainty = obj_
            obj_.original_tagname_ = 'certainty'
        elif nodeName_ == 'severity':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.severity = obj_
            obj_.original_tagname_ = 'severity'
        elif nodeName_ == 'onsetDate':
            obj_ = date.factory()
            obj_.build(child_)
            self.onsetDate = obj_
            obj_.original_tagname_ = 'onsetDate'
        elif nodeName_ == 'onsetAge':
            obj_ = Age.factory()
            obj_.build(child_)
            self.onsetAge = obj_
            obj_.original_tagname_ = 'onsetAge'
        elif nodeName_ == 'abatementDate':
            obj_ = date.factory()
            obj_.build(child_)
            self.abatementDate = obj_
            obj_.original_tagname_ = 'abatementDate'
        elif nodeName_ == 'abatementAge':
            obj_ = Age.factory()
            obj_.build(child_)
            self.abatementAge = obj_
            obj_.original_tagname_ = 'abatementAge'
        elif nodeName_ == 'abatementBoolean':
            obj_ = boolean.factory()
            obj_.build(child_)
            self.abatementBoolean = obj_
            obj_.original_tagname_ = 'abatementBoolean'
        elif nodeName_ == 'stage':
            obj_ = Condition_Stage.factory()
            obj_.build(child_)
            self.stage = obj_
            obj_.original_tagname_ = 'stage'
        elif nodeName_ == 'evidence':
            obj_ = Condition_Evidence.factory()
            obj_.build(child_)
            self.evidence.append(obj_)
            obj_.original_tagname_ = 'evidence'
        elif nodeName_ == 'location':
            obj_ = Condition_Location.factory()
            obj_.build(child_)
            self.location.append(obj_)
            obj_.original_tagname_ = 'location'
        elif nodeName_ == 'relatedItem':
            obj_ = Condition_RelatedItem.factory()
            obj_.build(child_)
            self.relatedItem.append(obj_)
            obj_.original_tagname_ = 'relatedItem'
        elif nodeName_ == 'notes':
            obj_ = string.factory()
            obj_.build(child_)
            self.notes = obj_
            obj_.original_tagname_ = 'notes'
        super(Condition, self).buildChildren(child_, node, nodeName_, True)
# end class Condition


class Condition_Stage(BackboneElement):
    """Use to record detailed information about conditions, problems or
    diagnoses recognized by a clinician. There are many uses
    including: recording a Diagnosis during an Encounter; populating
    a problem List or a Summary Statement, such as a Discharge
    Summary."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, summary=None, assessment=None):
        self.original_tagname_ = None
        super(Condition_Stage, self).__init__(id, extension, modifierExtension, )
        self.summary = summary
        if assessment is None:
            self.assessment = []
        else:
            self.assessment = assessment
    def factory(*args_, **kwargs_):
        if Condition_Stage.subclass:
            return Condition_Stage.subclass(*args_, **kwargs_)
        else:
            return Condition_Stage(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_summary(self): return self.summary
    def set_summary(self, summary): self.summary = summary
    def get_assessment(self): return self.assessment
    def set_assessment(self, assessment): self.assessment = assessment
    def add_assessment(self, value): self.assessment.append(value)
    def insert_assessment(self, index, value): self.assessment[index] = value
    def hasContent_(self):
        if (
            self.summary is not None or
            self.assessment or
            super(Condition_Stage, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Condition.Stage', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Stage')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Condition.Stage', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Condition.Stage'):
        super(Condition_Stage, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Stage')
    def exportChildren(self, outfile, level, namespace_='', name_='Condition.Stage', fromsubclass_=False, pretty_print=True):
        super(Condition_Stage, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.summary is not None:
            self.summary.export(outfile, level, namespace_, name_='summary', pretty_print=pretty_print)
        for assessment_ in self.assessment:
            assessment_.export(outfile, level, namespace_, name_='assessment', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Condition.Stage', mapping_=None):
        element = super(Condition_Stage, self).to_etree(parent_element, name_, mapping_)
        if self.summary is not None:
            summary_ = self.summary
            summary_.to_etree(element, name_='summary', mapping_=mapping_)
        for assessment_ in self.assessment:
            assessment_.to_etree(element, name_='assessment', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Condition_Stage, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'summary':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.summary = obj_
            obj_.original_tagname_ = 'summary'
        elif nodeName_ == 'assessment':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.assessment.append(obj_)
            obj_.original_tagname_ = 'assessment'
        super(Condition_Stage, self).buildChildren(child_, node, nodeName_, True)
# end class Condition_Stage


class Condition_Evidence(BackboneElement):
    """Use to record detailed information about conditions, problems or
    diagnoses recognized by a clinician. There are many uses
    including: recording a Diagnosis during an Encounter; populating
    a problem List or a Summary Statement, such as a Discharge
    Summary."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, code=None, detail=None):
        self.original_tagname_ = None
        super(Condition_Evidence, self).__init__(id, extension, modifierExtension, )
        self.code = code
        if detail is None:
            self.detail = []
        else:
            self.detail = detail
    def factory(*args_, **kwargs_):
        if Condition_Evidence.subclass:
            return Condition_Evidence.subclass(*args_, **kwargs_)
        else:
            return Condition_Evidence(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_code(self): return self.code
    def set_code(self, code): self.code = code
    def get_detail(self): return self.detail
    def set_detail(self, detail): self.detail = detail
    def add_detail(self, value): self.detail.append(value)
    def insert_detail(self, index, value): self.detail[index] = value
    def hasContent_(self):
        if (
            self.code is not None or
            self.detail or
            super(Condition_Evidence, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Condition.Evidence', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Evidence')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Condition.Evidence', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Condition.Evidence'):
        super(Condition_Evidence, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Evidence')
    def exportChildren(self, outfile, level, namespace_='', name_='Condition.Evidence', fromsubclass_=False, pretty_print=True):
        super(Condition_Evidence, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.code is not None:
            self.code.export(outfile, level, namespace_, name_='code', pretty_print=pretty_print)
        for detail_ in self.detail:
            detail_.export(outfile, level, namespace_, name_='detail', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Condition.Evidence', mapping_=None):
        element = super(Condition_Evidence, self).to_etree(parent_element, name_, mapping_)
        if self.code is not None:
            code_ = self.code
            code_.to_etree(element, name_='code', mapping_=mapping_)
        for detail_ in self.detail:
            detail_.to_etree(element, name_='detail', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Condition_Evidence, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'code':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.code = obj_
            obj_.original_tagname_ = 'code'
        elif nodeName_ == 'detail':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.detail.append(obj_)
            obj_.original_tagname_ = 'detail'
        super(Condition_Evidence, self).buildChildren(child_, node, nodeName_, True)
# end class Condition_Evidence


class Condition_Location(BackboneElement):
    """Use to record detailed information about conditions, problems or
    diagnoses recognized by a clinician. There are many uses
    including: recording a Diagnosis during an Encounter; populating
    a problem List or a Summary Statement, such as a Discharge
    Summary."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, code=None, detail=None):
        self.original_tagname_ = None
        super(Condition_Location, self).__init__(id, extension, modifierExtension, )
        self.code = code
        self.detail = detail
    def factory(*args_, **kwargs_):
        if Condition_Location.subclass:
            return Condition_Location.subclass(*args_, **kwargs_)
        else:
            return Condition_Location(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_code(self): return self.code
    def set_code(self, code): self.code = code
    def get_detail(self): return self.detail
    def set_detail(self, detail): self.detail = detail
    def hasContent_(self):
        if (
            self.code is not None or
            self.detail is not None or
            super(Condition_Location, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Condition.Location', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Location')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Condition.Location', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Condition.Location'):
        super(Condition_Location, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.Location')
    def exportChildren(self, outfile, level, namespace_='', name_='Condition.Location', fromsubclass_=False, pretty_print=True):
        super(Condition_Location, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.code is not None:
            self.code.export(outfile, level, namespace_, name_='code', pretty_print=pretty_print)
        if self.detail is not None:
            self.detail.export(outfile, level, namespace_, name_='detail', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Condition.Location', mapping_=None):
        element = super(Condition_Location, self).to_etree(parent_element, name_, mapping_)
        if self.code is not None:
            code_ = self.code
            code_.to_etree(element, name_='code', mapping_=mapping_)
        if self.detail is not None:
            detail_ = self.detail
            detail_.to_etree(element, name_='detail', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Condition_Location, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'code':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.code = obj_
            obj_.original_tagname_ = 'code'
        elif nodeName_ == 'detail':
            obj_ = string.factory()
            obj_.build(child_)
            self.detail = obj_
            obj_.original_tagname_ = 'detail'
        super(Condition_Location, self).buildChildren(child_, node, nodeName_, True)
# end class Condition_Location


class Condition_RelatedItem(BackboneElement):
    """Use to record detailed information about conditions, problems or
    diagnoses recognized by a clinician. There are many uses
    including: recording a Diagnosis during an Encounter; populating
    a problem List or a Summary Statement, such as a Discharge
    Summary."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, type_=None, code=None, target=None):
        self.original_tagname_ = None
        super(Condition_RelatedItem, self).__init__(id, extension, modifierExtension, )
        self.type_ = type_
        self.code = code
        self.target = target
    def factory(*args_, **kwargs_):
        if Condition_RelatedItem.subclass:
            return Condition_RelatedItem.subclass(*args_, **kwargs_)
        else:
            return Condition_RelatedItem(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_code(self): return self.code
    def set_code(self, code): self.code = code
    def get_target(self): return self.target
    def set_target(self, target): self.target = target
    def hasContent_(self):
        if (
            self.type_ is not None or
            self.code is not None or
            self.target is not None or
            super(Condition_RelatedItem, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Condition.RelatedItem', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.RelatedItem')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Condition.RelatedItem', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Condition.RelatedItem'):
        super(Condition_RelatedItem, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Condition.RelatedItem')
    def exportChildren(self, outfile, level, namespace_='', name_='Condition.RelatedItem', fromsubclass_=False, pretty_print=True):
        super(Condition_RelatedItem, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        if self.code is not None:
            self.code.export(outfile, level, namespace_, name_='code', pretty_print=pretty_print)
        if self.target is not None:
            self.target.export(outfile, level, namespace_, name_='target', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Condition.RelatedItem', mapping_=None):
        element = super(Condition_RelatedItem, self).to_etree(parent_element, name_, mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        if self.code is not None:
            code_ = self.code
            code_.to_etree(element, name_='code', mapping_=mapping_)
        if self.target is not None:
            target_ = self.target
            target_.to_etree(element, name_='target', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Condition_RelatedItem, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'type':
            obj_ = ConditionRelationshipType.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'code':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.code = obj_
            obj_.original_tagname_ = 'code'
        elif nodeName_ == 'target':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.target = obj_
            obj_.original_tagname_ = 'target'
        super(Condition_RelatedItem, self).buildChildren(child_, node, nodeName_, True)
# end class Condition_RelatedItem


class ConditionStatus(Element):
    """The clinical status of the Condition or diagnosisIf the element is
    present, it must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(ConditionStatus, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if ConditionStatus.subclass:
            return ConditionStatus.subclass(*args_, **kwargs_)
        else:
            return ConditionStatus(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(ConditionStatus, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='ConditionStatus', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='ConditionStatus')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='ConditionStatus', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='ConditionStatus'):
        super(ConditionStatus, self).exportAttributes(outfile, level, already_processed, namespace_, name_='ConditionStatus')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='ConditionStatus', fromsubclass_=False, pretty_print=True):
        super(ConditionStatus, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='ConditionStatus', mapping_=None):
        element = super(ConditionStatus, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(ConditionStatus, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(ConditionStatus, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class ConditionStatus


class ConditionRelationshipType(Element):
    """The type of relationship between a condition and its related itemIf
    the element is present, it must have either a @value, an @id, or
    extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(ConditionRelationshipType, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if ConditionRelationshipType.subclass:
            return ConditionRelationshipType.subclass(*args_, **kwargs_)
        else:
            return ConditionRelationshipType(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(ConditionRelationshipType, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='ConditionRelationshipType', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='ConditionRelationshipType')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='ConditionRelationshipType', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='ConditionRelationshipType'):
        super(ConditionRelationshipType, self).exportAttributes(outfile, level, already_processed, namespace_, name_='ConditionRelationshipType')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='ConditionRelationshipType', fromsubclass_=False, pretty_print=True):
        super(ConditionRelationshipType, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='ConditionRelationshipType', mapping_=None):
        element = super(ConditionRelationshipType, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(ConditionRelationshipType, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(ConditionRelationshipType, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class ConditionRelationshipType



class ProductionConfig(object):
    """A basic production config
    """
    TRYTON_DATABASE = '' #Change
    SECRET_KEY = ''    #Change
    SERVER_NAME = ""     #Set this

    PREFERRED_URL_SCHEME='https'
    SESSION_COOKIE_SECURE = True
    SESSION_COOKIE_NAME = 'fhir'
    PERMANENT_SESSION_LIFETIME = 24*60*60 #seconds

    #Remember Me setup
    REMEMBER_COOKIE_NAME='fhir_remember_token'
    #REMEMBER_COOKIE_DURATION #default 1 year

class DebugConfig(object):
    """Testing settings"""
    TRYTON_DATABASE='gnuhealth_demo_test'
    DEBUG = True
    SECRET_KEY = 'test'
    WTF_CSRF_ENABLED=False
    SESSION_COOKIE_NAME = 'fhir'
    REMEMBER_COOKIE_NAME='fhir_remember_token'



from .base_classes import *
from .support_functions import *


class Organization(Resource):
    """A formally or informally recognized grouping of people or
    organizations formed for the purpose of achieving some form of
    collective action. Includes companies, institutions,
    corporations, departments, community groups, healthcare practice
    groups, etc.If the element is present, it must have either a
    @value, an @id, or extensions"""
    subclass = None
    superclass = Resource
    def __init__(self, id=None, extension=None, modifierExtension=None, language=None, text=None, contained=None, identifier=None, name=None, type_=None, telecom=None, address=None, partOf=None, contact=None, location=None, active=None):
        self.original_tagname_ = None
        super(Organization, self).__init__(id, extension, modifierExtension, language, text, contained, )
        if identifier is None:
            self.identifier = []
        else:
            self.identifier = identifier
        self.name = name
        self.type_ = type_
        if telecom is None:
            self.telecom = []
        else:
            self.telecom = telecom
        if address is None:
            self.address = []
        else:
            self.address = address
        self.partOf = partOf
        if contact is None:
            self.contact = []
        else:
            self.contact = contact
        if location is None:
            self.location = []
        else:
            self.location = location
        self.active = active
    def factory(*args_, **kwargs_):
        if Organization.subclass:
            return Organization.subclass(*args_, **kwargs_)
        else:
            return Organization(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def add_identifier(self, value): self.identifier.append(value)
    def insert_identifier(self, index, value): self.identifier[index] = value
    def get_name(self): return self.name
    def set_name(self, name): self.name = name
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_telecom(self): return self.telecom
    def set_telecom(self, telecom): self.telecom = telecom
    def add_telecom(self, value): self.telecom.append(value)
    def insert_telecom(self, index, value): self.telecom[index] = value
    def get_address(self): return self.address
    def set_address(self, address): self.address = address
    def add_address(self, value): self.address.append(value)
    def insert_address(self, index, value): self.address[index] = value
    def get_partOf(self): return self.partOf
    def set_partOf(self, partOf): self.partOf = partOf
    def get_contact(self): return self.contact
    def set_contact(self, contact): self.contact = contact
    def add_contact(self, value): self.contact.append(value)
    def insert_contact(self, index, value): self.contact[index] = value
    def get_location(self): return self.location
    def set_location(self, location): self.location = location
    def add_location(self, value): self.location.append(value)
    def insert_location(self, index, value): self.location[index] = value
    def get_active(self): return self.active
    def set_active(self, active): self.active = active
    def hasContent_(self):
        if (
            self.identifier or
            self.name is not None or
            self.type_ is not None or
            self.telecom or
            self.address or
            self.partOf is not None or
            self.contact or
            self.location or
            self.active is not None or
            super(Organization, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Organization', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Organization')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Organization', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Organization'):
        super(Organization, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Organization')
    def exportChildren(self, outfile, level, namespace_='', name_='Organization', fromsubclass_=False, pretty_print=True):
        super(Organization, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        for identifier_ in self.identifier:
            identifier_.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        if self.name is not None:
            self.name.export(outfile, level, namespace_, name_='name', pretty_print=pretty_print)
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        for telecom_ in self.telecom:
            telecom_.export(outfile, level, namespace_, name_='telecom', pretty_print=pretty_print)
        for address_ in self.address:
            address_.export(outfile, level, namespace_, name_='address', pretty_print=pretty_print)
        if self.partOf is not None:
            self.partOf.export(outfile, level, namespace_, name_='partOf', pretty_print=pretty_print)
        for contact_ in self.contact:
            contact_.export(outfile, level, namespace_, name_='contact', pretty_print=pretty_print)
        for location_ in self.location:
            location_.export(outfile, level, namespace_, name_='location', pretty_print=pretty_print)
        if self.active is not None:
            self.active.export(outfile, level, namespace_, name_='active', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Organization', mapping_=None):
        element = super(Organization, self).to_etree(parent_element, name_, mapping_)
        for identifier_ in self.identifier:
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        if self.name is not None:
            name_ = self.name
            name_.to_etree(element, name_='name', mapping_=mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        for telecom_ in self.telecom:
            telecom_.to_etree(element, name_='telecom', mapping_=mapping_)
        for address_ in self.address:
            address_.to_etree(element, name_='address', mapping_=mapping_)
        if self.partOf is not None:
            partOf_ = self.partOf
            partOf_.to_etree(element, name_='partOf', mapping_=mapping_)
        for contact_ in self.contact:
            contact_.to_etree(element, name_='contact', mapping_=mapping_)
        for location_ in self.location:
            location_.to_etree(element, name_='location', mapping_=mapping_)
        if self.active is not None:
            active_ = self.active
            active_.to_etree(element, name_='active', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Organization, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'identifier':
            obj_ = Identifier.factory()
            obj_.build(child_)
            self.identifier.append(obj_)
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'name':
            obj_ = string.factory()
            obj_.build(child_)
            self.name = obj_
            obj_.original_tagname_ = 'name'
        elif nodeName_ == 'type':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'telecom':
            obj_ = Contact.factory()
            obj_.build(child_)
            self.telecom.append(obj_)
            obj_.original_tagname_ = 'telecom'
        elif nodeName_ == 'address':
            obj_ = Address.factory()
            obj_.build(child_)
            self.address.append(obj_)
            obj_.original_tagname_ = 'address'
        elif nodeName_ == 'partOf':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.partOf = obj_
            obj_.original_tagname_ = 'partOf'
        elif nodeName_ == 'contact':
            obj_ = Organization_Contact.factory()
            obj_.build(child_)
            self.contact.append(obj_)
            obj_.original_tagname_ = 'contact'
        elif nodeName_ == 'location':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.location.append(obj_)
            obj_.original_tagname_ = 'location'
        elif nodeName_ == 'active':
            obj_ = boolean.factory()
            obj_.build(child_)
            self.active = obj_
            obj_.original_tagname_ = 'active'
        super(Organization, self).buildChildren(child_, node, nodeName_, True)
# end class Organization


class Organization_Contact(BackboneElement):
    """A formally or informally recognized grouping of people or
    organizations formed for the purpose of achieving some form of
    collective action. Includes companies, institutions,
    corporations, departments, community groups, healthcare practice
    groups, etc."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, purpose=None, name=None, telecom=None, address=None, gender=None):
        self.original_tagname_ = None
        super(Organization_Contact, self).__init__(id, extension, modifierExtension, )
        self.purpose = purpose
        self.name = name
        if telecom is None:
            self.telecom = []
        else:
            self.telecom = telecom
        self.address = address
        self.gender = gender
    def factory(*args_, **kwargs_):
        if Organization_Contact.subclass:
            return Organization_Contact.subclass(*args_, **kwargs_)
        else:
            return Organization_Contact(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_purpose(self): return self.purpose
    def set_purpose(self, purpose): self.purpose = purpose
    def get_name(self): return self.name
    def set_name(self, name): self.name = name
    def get_telecom(self): return self.telecom
    def set_telecom(self, telecom): self.telecom = telecom
    def add_telecom(self, value): self.telecom.append(value)
    def insert_telecom(self, index, value): self.telecom[index] = value
    def get_address(self): return self.address
    def set_address(self, address): self.address = address
    def get_gender(self): return self.gender
    def set_gender(self, gender): self.gender = gender
    def hasContent_(self):
        if (
            self.purpose is not None or
            self.name is not None or
            self.telecom or
            self.address is not None or
            self.gender is not None or
            super(Organization_Contact, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Organization.Contact', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Organization.Contact')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Organization.Contact', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Organization.Contact'):
        super(Organization_Contact, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Organization.Contact')
    def exportChildren(self, outfile, level, namespace_='', name_='Organization.Contact', fromsubclass_=False, pretty_print=True):
        super(Organization_Contact, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.purpose is not None:
            self.purpose.export(outfile, level, namespace_, name_='purpose', pretty_print=pretty_print)
        if self.name is not None:
            self.name.export(outfile, level, namespace_, name_='name', pretty_print=pretty_print)
        for telecom_ in self.telecom:
            telecom_.export(outfile, level, namespace_, name_='telecom', pretty_print=pretty_print)
        if self.address is not None:
            self.address.export(outfile, level, namespace_, name_='address', pretty_print=pretty_print)
        if self.gender is not None:
            self.gender.export(outfile, level, namespace_, name_='gender', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Organization.Contact', mapping_=None):
        element = super(Organization_Contact, self).to_etree(parent_element, name_, mapping_)
        if self.purpose is not None:
            purpose_ = self.purpose
            purpose_.to_etree(element, name_='purpose', mapping_=mapping_)
        if self.name is not None:
            name_ = self.name
            name_.to_etree(element, name_='name', mapping_=mapping_)
        for telecom_ in self.telecom:
            telecom_.to_etree(element, name_='telecom', mapping_=mapping_)
        if self.address is not None:
            address_ = self.address
            address_.to_etree(element, name_='address', mapping_=mapping_)
        if self.gender is not None:
            gender_ = self.gender
            gender_.to_etree(element, name_='gender', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Organization_Contact, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'purpose':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.purpose = obj_
            obj_.original_tagname_ = 'purpose'
        elif nodeName_ == 'name':
            obj_ = HumanName.factory()
            obj_.build(child_)
            self.name = obj_
            obj_.original_tagname_ = 'name'
        elif nodeName_ == 'telecom':
            obj_ = Contact.factory()
            obj_.build(child_)
            self.telecom.append(obj_)
            obj_.original_tagname_ = 'telecom'
        elif nodeName_ == 'address':
            obj_ = Address.factory()
            obj_.build(child_)
            self.address = obj_
            obj_.original_tagname_ = 'address'
        elif nodeName_ == 'gender':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.gender = obj_
            obj_.original_tagname_ = 'gender'
        super(Organization_Contact, self).buildChildren(child_, node, nodeName_, True)
# end class Organization_Contact



from .base_classes import *
from .support_functions import *


class Location(Resource):
    """Details and position information for a physical place where services
    are provided and resources and participants may be stored,
    found, contained or accommodated.If the element is present, it
    must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Resource
    def __init__(self, id=None, extension=None, modifierExtension=None, language=None, text=None, contained=None, identifier=None, name=None, description=None, type_=None, telecom=None, address=None, physicalType=None, position=None, managingOrganization=None, status=None, partOf=None, mode=None):
        self.original_tagname_ = None
        super(Location, self).__init__(id, extension, modifierExtension, language, text, contained, )
        self.identifier = identifier
        self.name = name
        self.description = description
        self.type_ = type_
        if telecom is None:
            self.telecom = []
        else:
            self.telecom = telecom
        self.address = address
        self.physicalType = physicalType
        self.position = position
        self.managingOrganization = managingOrganization
        self.status = status
        self.partOf = partOf
        self.mode = mode
    def factory(*args_, **kwargs_):
        if Location.subclass:
            return Location.subclass(*args_, **kwargs_)
        else:
            return Location(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_identifier(self): return self.identifier
    def set_identifier(self, identifier): self.identifier = identifier
    def get_name(self): return self.name
    def set_name(self, name): self.name = name
    def get_description(self): return self.description
    def set_description(self, description): self.description = description
    def get_type(self): return self.type_
    def set_type(self, type_): self.type_ = type_
    def get_telecom(self): return self.telecom
    def set_telecom(self, telecom): self.telecom = telecom
    def add_telecom(self, value): self.telecom.append(value)
    def insert_telecom(self, index, value): self.telecom[index] = value
    def get_address(self): return self.address
    def set_address(self, address): self.address = address
    def get_physicalType(self): return self.physicalType
    def set_physicalType(self, physicalType): self.physicalType = physicalType
    def get_position(self): return self.position
    def set_position(self, position): self.position = position
    def get_managingOrganization(self): return self.managingOrganization
    def set_managingOrganization(self, managingOrganization): self.managingOrganization = managingOrganization
    def get_status(self): return self.status
    def set_status(self, status): self.status = status
    def get_partOf(self): return self.partOf
    def set_partOf(self, partOf): self.partOf = partOf
    def get_mode(self): return self.mode
    def set_mode(self, mode): self.mode = mode
    def hasContent_(self):
        if (
            self.identifier is not None or
            self.name is not None or
            self.description is not None or
            self.type_ is not None or
            self.telecom or
            self.address is not None or
            self.physicalType is not None or
            self.position is not None or
            self.managingOrganization is not None or
            self.status is not None or
            self.partOf is not None or
            self.mode is not None or
            super(Location, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Location', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Location')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Location', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Location'):
        super(Location, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Location')
    def exportChildren(self, outfile, level, namespace_='', name_='Location', fromsubclass_=False, pretty_print=True):
        super(Location, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.identifier is not None:
            self.identifier.export(outfile, level, namespace_, name_='identifier', pretty_print=pretty_print)
        if self.name is not None:
            self.name.export(outfile, level, namespace_, name_='name', pretty_print=pretty_print)
        if self.description is not None:
            self.description.export(outfile, level, namespace_, name_='description', pretty_print=pretty_print)
        if self.type_ is not None:
            self.type_.export(outfile, level, namespace_, name_='type', pretty_print=pretty_print)
        for telecom_ in self.telecom:
            telecom_.export(outfile, level, namespace_, name_='telecom', pretty_print=pretty_print)
        if self.address is not None:
            self.address.export(outfile, level, namespace_, name_='address', pretty_print=pretty_print)
        if self.physicalType is not None:
            self.physicalType.export(outfile, level, namespace_, name_='physicalType', pretty_print=pretty_print)
        if self.position is not None:
            self.position.export(outfile, level, namespace_, name_='position', pretty_print=pretty_print)
        if self.managingOrganization is not None:
            self.managingOrganization.export(outfile, level, namespace_, name_='managingOrganization', pretty_print=pretty_print)
        if self.status is not None:
            self.status.export(outfile, level, namespace_, name_='status', pretty_print=pretty_print)
        if self.partOf is not None:
            self.partOf.export(outfile, level, namespace_, name_='partOf', pretty_print=pretty_print)
        if self.mode is not None:
            self.mode.export(outfile, level, namespace_, name_='mode', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Location', mapping_=None):
        element = super(Location, self).to_etree(parent_element, name_, mapping_)
        if self.identifier is not None:
            identifier_ = self.identifier
            identifier_.to_etree(element, name_='identifier', mapping_=mapping_)
        if self.name is not None:
            name_ = self.name
            name_.to_etree(element, name_='name', mapping_=mapping_)
        if self.description is not None:
            description_ = self.description
            description_.to_etree(element, name_='description', mapping_=mapping_)
        if self.type_ is not None:
            type__ = self.type_
            type__.to_etree(element, name_='type', mapping_=mapping_)
        for telecom_ in self.telecom:
            telecom_.to_etree(element, name_='telecom', mapping_=mapping_)
        if self.address is not None:
            address_ = self.address
            address_.to_etree(element, name_='address', mapping_=mapping_)
        if self.physicalType is not None:
            physicalType_ = self.physicalType
            physicalType_.to_etree(element, name_='physicalType', mapping_=mapping_)
        if self.position is not None:
            position_ = self.position
            position_.to_etree(element, name_='position', mapping_=mapping_)
        if self.managingOrganization is not None:
            managingOrganization_ = self.managingOrganization
            managingOrganization_.to_etree(element, name_='managingOrganization', mapping_=mapping_)
        if self.status is not None:
            status_ = self.status
            status_.to_etree(element, name_='status', mapping_=mapping_)
        if self.partOf is not None:
            partOf_ = self.partOf
            partOf_.to_etree(element, name_='partOf', mapping_=mapping_)
        if self.mode is not None:
            mode_ = self.mode
            mode_.to_etree(element, name_='mode', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Location, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'identifier':
            obj_ = Identifier.factory()
            obj_.build(child_)
            self.identifier = obj_
            obj_.original_tagname_ = 'identifier'
        elif nodeName_ == 'name':
            obj_ = string.factory()
            obj_.build(child_)
            self.name = obj_
            obj_.original_tagname_ = 'name'
        elif nodeName_ == 'description':
            obj_ = string.factory()
            obj_.build(child_)
            self.description = obj_
            obj_.original_tagname_ = 'description'
        elif nodeName_ == 'type':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.type_ = obj_
            obj_.original_tagname_ = 'type'
        elif nodeName_ == 'telecom':
            obj_ = Contact.factory()
            obj_.build(child_)
            self.telecom.append(obj_)
            obj_.original_tagname_ = 'telecom'
        elif nodeName_ == 'address':
            obj_ = Address.factory()
            obj_.build(child_)
            self.address = obj_
            obj_.original_tagname_ = 'address'
        elif nodeName_ == 'physicalType':
            obj_ = CodeableConcept.factory()
            obj_.build(child_)
            self.physicalType = obj_
            obj_.original_tagname_ = 'physicalType'
        elif nodeName_ == 'position':
            obj_ = Location_Position.factory()
            obj_.build(child_)
            self.position = obj_
            obj_.original_tagname_ = 'position'
        elif nodeName_ == 'managingOrganization':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.managingOrganization = obj_
            obj_.original_tagname_ = 'managingOrganization'
        elif nodeName_ == 'status':
            obj_ = LocationStatus.factory()
            obj_.build(child_)
            self.status = obj_
            obj_.original_tagname_ = 'status'
        elif nodeName_ == 'partOf':
            obj_ = ResourceReference.factory()
            obj_.build(child_)
            self.partOf = obj_
            obj_.original_tagname_ = 'partOf'
        elif nodeName_ == 'mode':
            obj_ = LocationMode.factory()
            obj_.build(child_)
            self.mode = obj_
            obj_.original_tagname_ = 'mode'
        super(Location, self).buildChildren(child_, node, nodeName_, True)
# end class Location


class Location_Position(BackboneElement):
    """Details and position information for a physical place where services
    are provided and resources and participants may be stored,
    found, contained or accommodated."""
    subclass = None
    superclass = BackboneElement
    def __init__(self, id=None, extension=None, modifierExtension=None, longitude=None, latitude=None, altitude=None):
        self.original_tagname_ = None
        super(Location_Position, self).__init__(id, extension, modifierExtension, )
        self.longitude = longitude
        self.latitude = latitude
        self.altitude = altitude
    def factory(*args_, **kwargs_):
        if Location_Position.subclass:
            return Location_Position.subclass(*args_, **kwargs_)
        else:
            return Location_Position(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_longitude(self): return self.longitude
    def set_longitude(self, longitude): self.longitude = longitude
    def get_latitude(self): return self.latitude
    def set_latitude(self, latitude): self.latitude = latitude
    def get_altitude(self): return self.altitude
    def set_altitude(self, altitude): self.altitude = altitude
    def hasContent_(self):
        if (
            self.longitude is not None or
            self.latitude is not None or
            self.altitude is not None or
            super(Location_Position, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='Location.Position', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='Location.Position')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='Location.Position', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='Location.Position'):
        super(Location_Position, self).exportAttributes(outfile, level, already_processed, namespace_, name_='Location.Position')
    def exportChildren(self, outfile, level, namespace_='', name_='Location.Position', fromsubclass_=False, pretty_print=True):
        super(Location_Position, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.longitude is not None:
            self.longitude.export(outfile, level, namespace_, name_='longitude', pretty_print=pretty_print)
        if self.latitude is not None:
            self.latitude.export(outfile, level, namespace_, name_='latitude', pretty_print=pretty_print)
        if self.altitude is not None:
            self.altitude.export(outfile, level, namespace_, name_='altitude', pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='Location.Position', mapping_=None):
        element = super(Location_Position, self).to_etree(parent_element, name_, mapping_)
        if self.longitude is not None:
            longitude_ = self.longitude
            longitude_.to_etree(element, name_='longitude', mapping_=mapping_)
        if self.latitude is not None:
            latitude_ = self.latitude
            latitude_.to_etree(element, name_='latitude', mapping_=mapping_)
        if self.altitude is not None:
            altitude_ = self.altitude
            altitude_.to_etree(element, name_='altitude', mapping_=mapping_)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        super(Location_Position, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        if nodeName_ == 'longitude':
            obj_ = decimal.factory()
            obj_.build(child_)
            self.longitude = obj_
            obj_.original_tagname_ = 'longitude'
        elif nodeName_ == 'latitude':
            obj_ = decimal.factory()
            obj_.build(child_)
            self.latitude = obj_
            obj_.original_tagname_ = 'latitude'
        elif nodeName_ == 'altitude':
            obj_ = decimal.factory()
            obj_.build(child_)
            self.altitude = obj_
            obj_.original_tagname_ = 'altitude'
        super(Location_Position, self).buildChildren(child_, node, nodeName_, True)
# end class Location_Position


class LocationStatus(Element):
    """Indicates whether the location is still in useIf the element is
    present, it must have either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(LocationStatus, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if LocationStatus.subclass:
            return LocationStatus.subclass(*args_, **kwargs_)
        else:
            return LocationStatus(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(LocationStatus, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='LocationStatus', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='LocationStatus')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='LocationStatus', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='LocationStatus'):
        super(LocationStatus, self).exportAttributes(outfile, level, already_processed, namespace_, name_='LocationStatus')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='LocationStatus', fromsubclass_=False, pretty_print=True):
        super(LocationStatus, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='LocationStatus', mapping_=None):
        element = super(LocationStatus, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(LocationStatus, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(LocationStatus, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class LocationStatus


class LocationMode(Element):
    """Indicates whether a resource instance represents a specific location
    or a class of locationsIf the element is present, it must have
    either a @value, an @id, or extensions"""
    subclass = None
    superclass = Element
    def __init__(self, id=None, extension=None, value=None):
        self.original_tagname_ = None
        super(LocationMode, self).__init__(id, extension, )
        self.value = _cast(None, value)
    def factory(*args_, **kwargs_):
        if LocationMode.subclass:
            return LocationMode.subclass(*args_, **kwargs_)
        else:
            return LocationMode(*args_, **kwargs_)
    factory = staticmethod(factory)
    def get_value(self): return self.value
    def set_value(self, value): self.value = value
    def hasContent_(self):
        if (
            super(LocationMode, self).hasContent_()
        ):
            return True
        else:
            return False
    def export(self, outfile, level, namespace_='', name_='LocationMode', namespacedef_='', pretty_print=True):
        if pretty_print:
            eol_ = '\n'
        else:
            eol_ = ''
        if self.original_tagname_ is not None:
            name_ = self.original_tagname_
        showIndent(outfile, level, pretty_print)
        outfile.write('<%s%s%s' % (namespace_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
        already_processed = set()
        self.exportAttributes(outfile, level, already_processed, namespace_, name_='LocationMode')
        if self.hasContent_():
            outfile.write('>%s' % (eol_, ))
            self.exportChildren(outfile, level + 1, namespace_='', name_='LocationMode', pretty_print=pretty_print)
            showIndent(outfile, level, pretty_print)
            outfile.write('</%s%s>%s' % (namespace_, name_, eol_))
        else:
            outfile.write('/>%s' % (eol_, ))
    def exportAttributes(self, outfile, level, already_processed, namespace_='', name_='LocationMode'):
        super(LocationMode, self).exportAttributes(outfile, level, already_processed, namespace_, name_='LocationMode')
        if self.value is not None and 'value' not in already_processed:
            already_processed.add('value')
            outfile.write(' value=%s' % (quote_attrib(self.value), ))
    def exportChildren(self, outfile, level, namespace_='', name_='LocationMode', fromsubclass_=False, pretty_print=True):
        super(LocationMode, self).exportChildren(outfile, level, namespace_, name_, True, pretty_print=pretty_print)
    def to_etree(self, parent_element=None, name_='LocationMode', mapping_=None):
        element = super(LocationMode, self).to_etree(parent_element, name_, mapping_)
        if self.value is not None:
            element.set('value', self.value)
        if mapping_ is not None:
            mapping_[self] = element
        return element
    def build(self, node):
        already_processed = set()
        self.buildAttributes(node, node.attrib, already_processed)
        for child in node:
            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
            self.buildChildren(child, node, nodeName_)
        return self
    def buildAttributes(self, node, attrs, already_processed):
        value = find_attr_value_('value', node)
        if value is not None and 'value' not in already_processed:
            already_processed.add('value')
            self.value = value
        super(LocationMode, self).buildAttributes(node, attrs, already_processed)
    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False):
        super(LocationMode, self).buildChildren(child_, node, nodeName_, True)
        pass
# end class LocationMode
